@@ -1,4 +1,4 @@
-from sqlalchemy import Column, JSON
+from sqlalchemy import Column, JSON, Integer, Identity, TEXT
 from sqlmodel import Field
 
 from sql_models.SQLCamelModel import SQLCamelModel
@@ -11,18 +11,20 @@ from sql_models.motorcycle_model.MotorcycleModel import MotorcycleModel
 class MotorcycleModelEntity(RoleVisibility, SQLCamelModel, table=True):
     __tablename__ = 'models'
 
-    id: str = Field(
+    id: int = Field(
         primary_key=True,
-        # max_length=32,
+        sa_column=Column(Integer, Identity(start=0, cycle=True)),
     )
 
-    manufacturer_id: str = Field(
-        primary_key=True,
+    manufacturer_id: int = Field(
         foreign_key='manufacturer.id',
-        # max_length=32,
     )
 
-    model_info: MotorcycleModel | None = Field(
+    name: str = Field(
+        sa_column=Column(TEXT)
+    )
+
+    technical_info: MotorcycleModel | None = Field(
         default=None,
         sa_column=Column(JSON),
     )
